==> haskell-hslogger-1.2.12-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.12
id: hslogger-1.2.12-6X5EhFZpevJJUrwRv5v1kp
key: hslogger-1.2.12-6X5EhFZpevJJUrwRv5v1kp
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
abi: 7089c251dd67b8662f5e47651040955a
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
import-dirs: /usr/lib/ghc-8.6.1/site-local/hslogger-1.2.12
library-dirs: /usr/lib/ghc-8.6.1/site-local/hslogger-1.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/hslogger-1.2.12
hs-libraries: HShslogger-1.2.12-6X5EhFZpevJJUrwRv5v1kp
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    network-2.7.0.2-11unSY69gPCAmgeVCL0SxR
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 process-1.6.3.0
    time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslogger-1.2.12-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.12
id: hslogger-1.2.12-JpNeI8YK5pqH9RUxpqKoNT
key: hslogger-1.2.12-JpNeI8YK5pqH9RUxpqKoNT
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
abi: 9642ad366bc16ed9a54b41b2491e689a
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
import-dirs: /usr/lib/ghc-8.6.1/site-local/hslogger-1.2.12
library-dirs: /usr/lib/ghc-8.6.1/site-local/hslogger-1.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/hslogger-1.2.12
hs-libraries: HShslogger-1.2.12-JpNeI8YK5pqH9RUxpqKoNT
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    network-2.7.0.2-Fxn7IKbIXjq1GwNvEyamvn
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 process-1.6.3.0
    time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
